BloomFilter

Struct BloomFilter 

pub struct BloomFilter<const N: usize, const K: usize = 2> { /* private fields */ }
A Bloom filter, parameterized by number of u64 segments N and number of hash functions K.

N should be based on how much you plan to insert into the filter. N * 64 should be at least the number of items you plan to insert.

K if how little you can tolerate false positives. 2, the default, should work for most uses. Increase K to reduce false positives, at a pretty large compute cost.

Examples

use bevy_utils::BloomFilter;

let mut filter = BloomFilter::<1>::new();
filter.insert(&"hello");
assert!(filter.contains(&"hello"));
assert!(!filter.contains(&"world"));

Implementations

Source

impl<const N: usize, const K: usize> BloomFilter<N, K>

pub const fn new() -> Self

Creates a new, empty filter.

pub fn insert(&mut self, item: &impl Hash)

Inserts a value into the filter.

pub fn contains(&self, item: &impl Hash) -> bool

Checks if the filter might contain the value.

pub fn check_insert(&mut self, item: &impl Hash) -> bool

Combined Self::contains and Self::insert.

Returns true if the value was already in the filter. Adds the value to the filter if it was not already present.